[![Runbot Status](https://runbot.odoo-community.org/runbot/badge/flat/205/10.0.svg)](https://runbot.odoo-community.org/runbot/repo/github-com-oca-social-205)
[![Build Status](https://travis-ci.org/OCA/social.svg?branch=10.0)](https://travis-ci.org/OCA/social)
[![Coverage Status](https://coveralls.io/repos/OCA/social/badge.svg?branch=10.0)](https://coveralls.io/r/OCA/social?branch=10.0)

Social addons for Odoo
======================

Addons concerning Odoo's social ERP features and messaging in general

[//]: # (addons)

Available addons
----------------
addon | version | summary
--- | --- | ---
[email_template_qweb](email_template_qweb/) | 10.0.1.0.0 | Use the QWeb templating mechanism for emails
[mail_as_letter](mail_as_letter/) | 10.0.1.0.0 | This module allows to download a mail message as a pdf letter.
[mail_attach_existing_attachment](mail_attach_existing_attachment/) | 10.0.1.0.0 | Adding attachment on the object by sending this one
[mail_full_expand](mail_full_expand/) | 10.0.1.0.0 | Expand mail in a big window
[mail_optional_autofollow](mail_optional_autofollow/) | 10.0.1.0.0 | Choose if you want to automatically add new recipients as followers on mail.compose.message
[mail_restrict_follower_selection](mail_restrict_follower_selection/) | 10.0.1.0.0 | Define a domain from which followers can be selected
[mail_tracking](mail_tracking/) | 10.0.1.0.0 | Email tracking system for all mails sent
[mail_tracking_mailgun](mail_tracking_mailgun/) | 10.0.1.0.0 | Mail tracking and Mailgun webhooks integration


Unported addons
---------------
addon | version | summary
--- | --- | ---
[mail_compose_select_lang](mail_compose_select_lang/) | 8.0.1.0.0 (unported) | Select language in mail compose window
[mass_mailing_custom_unsubscribe](mass_mailing_custom_unsubscribe/) | 8.0.1.0.0 (unported) | Customizable unsubscribe link on mass mailing emails

[//]: # (end addons)

Translation Status
------------------
[![Transifex Status](https://www.transifex.com/projects/p/OCA-social-10-0/chart/image_png)](https://www.transifex.com/projects/p/OCA-social-10-0)
